require 'net/http'
require 'json'
require 'digest/sha1'

class XmonApiException < Exception; end

class XmonApi
    def initialize(host, port, user, authToken)
        @host = host
        @port = port
        @user = user
        @authToken = authToken
    end

    def request(method, data)
        json_body = self.getJsonBody
        json_body['method'] = method
        json_body['params'] = {}
        params = data
        params.each do |key, value|
          unless value.nil?
              json_body['params'].store(key, value)
          end
        end

        response = nil

        request = Net::HTTP::Post.new('/1.0/xmon_api.php', initheader = {'Content-Type' =>'application/json'})
        request.body = json_body.to_json

        http = Net::HTTP.new(@host, @port)

        http.start do |h|
            response = h.request(request)
        end

        result = JSON.parse(response.body)

        if result.key?('error')
            @result = result
            raise XmonApiException, response.body
        end

        return result['result']
    end

    def getError
        err = sprintf("Error: %s %s %s\n", @result['error']['code'], @result['error']['message'], @result['error']['data']) 
        if @result['error'].key?('invalid')
             @result['error']['invalid'].each{|key, value|
                 err = err + key + ':' + value + "\n"
             }
        end
        return err
    end

    def getJsonBody
        json_body = { :jsonrpc => 2.0 }
        json_body['id'] = Digest::SHA1.hexdigest(Time.now.to_s);
        json_body['user_id'] = @user
        json_body['auth_token'] = @authToken

        return json_body
    end
end


